@@ -58,7 +58,7 @@ class TodoMixin(Generic[T], abc.ABC):
         if self.done:
             kwargs["done"] = self.done
 
-        if self.metadata is not None:
+        if self.metadata:
             kwargs["metadata"] = self.metadata
 
         if self.priority != DEFAULT_PRIORITY:
@@ -76,6 +76,9 @@ class TodoMixin(Generic[T], abc.ABC):
 
         return f"{cname(self)}(desc={self.desc!r}{pretty_kwargs})"
 
+    def __hash__(self: T) -> int:  # noqa: D105
+        return hash(self.metadata.values())
+
     def __eq__(self: T, other: object) -> bool:  # noqa: D105
         if not isinstance(other, type(self)):  # pragma: no cover
             return False
@@ -148,6 +151,8 @@ class TodoMixin(Generic[T], abc.ABC):
 class Todo(TodoMixin):
     """Represents a single task in a todo list."""
 
+    ident = "BASIC TODO"
+
     def __init__(
         self,
         desc: str,
